@@ -16,10 +16,18 @@ from .notifications import (
     EveEntity,
     FuelAlert,
     FuelAlertConfig,
+    JumpFuelAlert,
+    JumpFuelAlertConfig,
     Notification,
     NotificationType,
     Webhook,
     get_default_notification_types,
 )
-from .owners import Owner, OwnerAsset, OwnerCharacter
-from .structures import PocoDetails, Structure, StructureService, StructureTag
+from .owners import Owner, OwnerCharacter
+from .structures import (
+    PocoDetails,
+    Structure,
+    StructureItem,
+    StructureService,
+    StructureTag,
+)
