@@ -201,7 +201,9 @@ class Owner(models.Model):
         if self.is_alliance_main:
             Owner.objects.filter(
                 corporation__alliance_id=self.corporation.alliance_id
-            ).update(is_alliance_main=False)
+            ).exclude(corporation__alliance_id__isnull=True).update(
+                is_alliance_main=False
+            )
             if "update_fields" in kwargs:
                 kwargs["update_fields"].append("is_alliance_main")
         super().save(*args, **kwargs)
@@ -1174,6 +1176,7 @@ class Owner(models.Model):
 
     def update_asset_esi(self, user: User = None):
         assets_in_structures = self._fetch_structure_assets_from_esi()
+        StructureItem.objects.filter(structure__owner=self).delete()  # clear all items
         for structure in self.structures.all():
             if structure.id in assets_in_structures.keys():
                 structure_assets = assets_in_structures[structure.id]
@@ -1212,11 +1215,6 @@ class Owner(models.Model):
 
             structure.reevaluate_jump_fuel_alerts()
 
-        # remove items from structures that no longer have items
-        StructureItem.objects.filter(structure__owner=self).exclude(
-            structure_id__in=assets_in_structures.keys()
-        ).delete()
-
         self.assets_last_update_at = now()
         self.save(update_fields=["assets_last_update_at"])
         if user:
